==> apache-trafficcontrol-5.1.6.tar.gz: apache-trafficcontrol-5.1.6/traffic_portal/app/src/modules/private/serverCapabilities/servers/index.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

module.exports = angular.module('trafficPortal.private.serverCapabilities.servers', [])
	.config(function($stateProvider, $urlRouterProvider) {
		$stateProvider
			.state('trafficPortal.private.serverCapabilities.servers', {
				url: '/{serverCapability}/servers',
				views: {
					serverCapabilitiesContent: {
						templateUrl: 'common/modules/table/serverCapabilityServers/table.serverCapabilityServers.tpl.html',
						controller: 'TableServerCapabilityServersController',
						resolve: {
							serverCapability: function($stateParams, serverCapabilityService) {
								return serverCapabilityService.getServerCapability($stateParams.serverCapability);
							},
							servers: function($stateParams, serverCapabilityService) {
								return serverCapabilityService.getServerCapabilityServers($stateParams.serverCapability);
							}
						}
					}
				}
			})
		;
		$urlRouterProvider.otherwise('/');
	});

==> apache-trafficcontrol-8.0.2.tar.gz: apache-trafficcontrol-8.0.2/traffic_portal/app/src/modules/private/serverCapabilities/servers/index.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

module.exports = angular.module('trafficPortal.private.serverCapabilities.servers', [])
	.config(function($stateProvider, $urlRouterProvider) {
		$stateProvider
			.state('trafficPortal.private.serverCapabilities.servers', {
				url: '/servers?name',
				views: {
					serverCapabilitiesContent: {
						templateUrl: 'common/modules/table/serverCapabilityServers/table.serverCapabilityServers.tpl.html',
						controller: 'TableServerCapabilityServersController',
						resolve: {
							serverCapability: function($stateParams, serverCapabilityService) {
								return serverCapabilityService.getServerCapability($stateParams.name);
							},
							servers: function($stateParams, serverCapabilityService) {
								return serverCapabilityService.getServerCapabilityServers($stateParams.name);
							}
						}
					}
				}
			})
		;
		$urlRouterProvider.otherwise('/');
	});
